@@ -26,18 +26,16 @@
 #include <QVBoxLayout>
 #include <QGridLayout>
 
+#include <KConfigGroup>
 #include <KLocalizedString>
-#include <KDialog>
 #include <KKeySequenceWidget>
-#include <KLineEdit>
+#include <QLineEdit>
 #include <KIconButton>
 #include <KDesktopFile>
 #include <KUrlRequester>
 #include <KShell>
 
-#ifndef Q_OS_WIN
-#include "khotkeys.h"
-#endif
+#include "globalaccel.h"
 
 #include "klinespellchecking.h"
 #include "menuinfo.h"
@@ -49,11 +47,6 @@ BasicTab::BasicTab(QWidget *parent)
     initAdvancedTab();
     initConnections();
 
-#ifdef WITH_HOTKEYS
-    if (!KHotKeys::present()) {
-        _keyBindingGroup->hide();
-    }
-#endif
     slotDisableAction();
 }
 
@@ -62,15 +55,14 @@ void BasicTab::initGeneralTab()
     // general tab
     QWidget *generalTab = new QWidget();
     QGridLayout *generalTabLayout = new QGridLayout(generalTab);
-    generalTabLayout->setMargin(KDialog::marginHint());
-    generalTabLayout->setSpacing(KDialog::spacingHint());
     generalTab->setAcceptDrops(false);
 
     // name
     _nameLabel = new QLabel(i18n("&Name:"));
     generalTabLayout->addWidget(_nameLabel, 0, 0);
-    _nameEdit = new KLineEdit();
+    _nameEdit = new QLineEdit();
     _nameEdit->setAcceptDrops(false);
+    _nameEdit->setClearButtonEnabled(true);
     _nameLabel->setBuddy(_nameEdit);
     generalTabLayout->addWidget(_nameEdit, 0, 1, 1, 1);
 
@@ -143,8 +135,6 @@ void BasicTab::initAdvancedTab()
     // work path
     _workPathGroup = new QGroupBox();
     QHBoxLayout *workPathGroupLayout = new QHBoxLayout(_workPathGroup);
-    workPathGroupLayout->setSpacing(KDialog::spacingHint());
-    workPathGroupLayout->setMargin(KDialog::marginHint());
     _pathLabel = new QLabel(i18n("&Work path:"));
     workPathGroupLayout->addWidget(_pathLabel);
     _pathEdit = new KUrlRequester();
@@ -157,17 +147,15 @@ void BasicTab::initAdvancedTab()
     // terminal CB
     _terminalGroup = new QGroupBox();
     QVBoxLayout *terminalGroupLayout = new QVBoxLayout(_terminalGroup);
-    terminalGroupLayout->setMargin(KDialog::marginHint());
-    terminalGroupLayout->setSpacing(KDialog::spacingHint());
     _terminalCB = new QCheckBox(i18n("Run in term&inal"));
     terminalGroupLayout->addWidget(_terminalCB);
     // terminal options
     QWidget *terminalOptionsGroup = new QWidget();
     QHBoxLayout *terminalOptionsGroupLayout = new QHBoxLayout(terminalOptionsGroup);
-    terminalOptionsGroupLayout->setSpacing(KDialog::spacingHint());
     _terminalOptionsLabel = new QLabel(i18n("Terminal &options:"));
     terminalOptionsGroupLayout->addWidget(_terminalOptionsLabel);
-    _terminalOptionsEdit = new KLineEdit();
+    _terminalOptionsEdit = new QLineEdit();
+    _terminalOptionsEdit->setClearButtonEnabled(true);
     _terminalOptionsEdit->setAcceptDrops(false);
     _terminalOptionsEdit->setEnabled(false);
     _terminalOptionsLabel->setBuddy(_terminalOptionsEdit);
@@ -178,17 +166,15 @@ void BasicTab::initAdvancedTab()
     // user name CB
     _userGroup = new QGroupBox();
     QVBoxLayout *userGroupLayout = new QVBoxLayout(_userGroup);
-    userGroupLayout->setMargin(KDialog::marginHint());
-    userGroupLayout->setSpacing(KDialog::spacingHint());
     _userCB = new QCheckBox(i18n("&Run as a different user"));
     userGroupLayout->addWidget(_userCB);
     // user name
     QWidget *userNameGroup = new QWidget();
     QHBoxLayout *userNameGroupLayout = new QHBoxLayout(userNameGroup);
-    userNameGroupLayout->setSpacing(KDialog::spacingHint());
     _userNameLabel = new QLabel(i18n("&Username:"));
     userNameGroupLayout->addWidget(_userNameLabel);
-    _userNameEdit = new KLineEdit();
+    _userNameEdit = new QLineEdit();
+    _userNameEdit->setClearButtonEnabled(true);
     _userNameEdit->setAcceptDrops(false);
     _userNameEdit->setEnabled(false);
     _userNameLabel->setBuddy(_userNameEdit);
@@ -199,8 +185,6 @@ void BasicTab::initAdvancedTab()
     // key binding
     _keyBindingGroup = new QGroupBox();
     QHBoxLayout *keyBindingGroupLayout = new QHBoxLayout(_keyBindingGroup);
-    keyBindingGroupLayout->setMargin(KDialog::marginHint());
-    keyBindingGroupLayout->setSpacing(KDialog::spacingHint());
     _keyBindingLabel = new QLabel(i18n("Current shortcut &key:"));
     keyBindingGroupLayout->addWidget(_keyBindingLabel);
     _keyBindingEdit = new KKeySequenceWidget();
@@ -218,7 +202,7 @@ void BasicTab::initAdvancedTab()
 void BasicTab::initConnections()
 {
     // general tab's components
-    connect(_nameEdit, &KLineEdit::textChanged, this, &BasicTab::slotChanged);
+    connect(_nameEdit, &QLineEdit::textChanged, this, &BasicTab::slotChanged);
     connect(_descriptionEdit, &KLineSpellChecking::textChanged, this, &BasicTab::slotChanged);
     connect(_commentEdit, &KLineSpellChecking::textChanged, this, &BasicTab::slotChanged);
     connect(_execEdit, &KUrlRequester::textChanged, this, &BasicTab::slotChanged);
@@ -231,9 +215,9 @@ void BasicTab::initConnections()
     // advanced tab's components
     connect(_pathEdit, &KUrlRequester::textChanged, this, &BasicTab::slotChanged);
     connect(_terminalCB, &QCheckBox::clicked, this, &BasicTab::termcb_clicked);
-    connect(_terminalOptionsEdit, &KLineEdit::textChanged, this, &BasicTab::slotChanged);
+    connect(_terminalOptionsEdit, &QLineEdit::textChanged, this, &BasicTab::slotChanged);
     connect(_userCB, &QCheckBox::clicked, this, &BasicTab::uidcb_clicked);
-    connect(_userNameEdit, &KLineEdit::textChanged, this, &BasicTab::slotChanged);
+    connect(_userNameEdit, &QLineEdit::textChanged, this, &BasicTab::slotChanged);
     connect(_keyBindingEdit, &KKeySequenceWidget::keySequenceChanged, this, &BasicTab::slotCapturedKeySequence);
 }
 
@@ -358,15 +342,11 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
     _iconButton->setIcon(df->readIcon());
 
     // key binding part
-#ifdef WITH_HOTKEYS
-    if (KHotKeys::present()) {
-        if (!entryInfo->shortcut().isEmpty()) {
-            _keyBindingEdit->setKeySequence(entryInfo->shortcut());
-        } else {
-            _keyBindingEdit->clearKeySequence();
-        }
+    if (!entryInfo->shortcut().isEmpty()) {
+        _keyBindingEdit->setKeySequence(entryInfo->shortcut());
+    } else {
+        _keyBindingEdit->clearKeySequence();
     }
-#endif
     _execEdit->lineEdit()->setText(df->desktopGroup().readEntry("Exec"));
 
     _pathEdit->lineEdit()->setText(df->readPath());
@@ -505,14 +485,12 @@ void BasicTab::slotCapturedKeySequence(const QKeySequence &seq)
         return;
     }
     QKeySequence cut(seq);
-#ifdef WITH_HOTKEYS
-    if (_menuEntryInfo->isShortcutAvailable(cut) && KHotKeys::present()) {
+    if (_menuEntryInfo->isShortcutAvailable(cut)) {
         _menuEntryInfo->setShortcut(cut);
     } else {
         // We will not assign the shortcut so reset the visible key sequence
         _keyBindingEdit->setKeySequence(QKeySequence());
     }
-#endif
     if (_menuEntryInfo) {
         emit changed(_menuEntryInfo);
     }
