@@ -27,24 +27,23 @@ class KLineSpellChecking : public KLineEdit
 {
     Q_OBJECT
 public:
-    KLineSpellChecking( QWidget *parent = 0 );
-    ~KLineSpellChecking();
+    explicit KLineSpellChecking(QWidget *parent = nullptr);
+    ~KLineSpellChecking() override;
 
-    void highLightWord( unsigned int length, unsigned int pos );
+    void highLightWord(int length, int pos);
 
 protected:
-    void contextMenuEvent(QContextMenuEvent *e) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *e) override;
 
 private Q_SLOTS:
     void slotCheckSpelling();
-    void slotSpellCheckDone( const QString &s );
-    void spellCheckerMisspelling( const QString &text, int pos);
-    void spellCheckerCorrected( const QString &, int, const QString &);
+    void slotSpellCheckDone(const QString &s);
+    void spellCheckerMisspelling(const QString &text, int pos);
+    void spellCheckerCorrected(const QString &, int, const QString &);
     void spellCheckerFinished();
 
 private:
     QAction *m_spellAction;
 };
 
-
 #endif
